@@ -16,6 +16,7 @@ import json
 import sys
 import os
 import re
+import ssl
 import stat
 import logging
 import operator
@@ -46,7 +47,7 @@ except ImportError:  # pragma: no cover (py3 only)
 
 from pkg_resources import parse_version
 
-nodeenv_version = '1.4.0'
+nodeenv_version = '1.5.0'
 
 join = os.path.join
 abspath = os.path.abspath
@@ -54,8 +55,9 @@ src_base_url = None
 
 is_PY3 = sys.version_info[0] >= 3
 is_WIN = platform.system() == 'Windows'
-is_CYGWIN = platform.system().startswith('CYGWIN')
+is_CYGWIN = platform.system().startswith(('CYGWIN', 'MSYS'))
 
+ignore_ssl_certs = False
 
 # ---------------------------------------------------------
 # Utils
@@ -97,6 +99,7 @@ class Config(object):
     profile = False
     make = 'make'
     prebuilt = True
+    ignore_ssl_certs = False
 
     @classmethod
     def _load(cls, configfiles, verbose=False):
@@ -341,7 +344,13 @@ def parse_args(check=True):
         action='store_true', default=Config.prebuilt,
         help='Install node.js from prebuilt package (default)')
 
+    parser.add_option(
+        '--ignore_ssl_certs', dest='ignore_ssl_certs',
+        action='store_true', default=Config.ignore_ssl_certs,
+        help='Ignore certificates for package downloads. - UNSAFE -')
+
     options, args = parser.parse_args()
+
     if options.config_file is None:
         options.config_file = ["./tox.ini", "./setup.cfg", "~/.nodeenvrc"]
     elif not options.config_file:
@@ -513,7 +522,10 @@ def get_node_bin_url(version):
         'AMD64':  'x64',  # Windows Server 2012 R2 (x64)
         'armv6l': 'armv6l',     # arm
         'armv7l': 'armv7l',
+        'armv8l': 'armv7l',
         'aarch64': 'arm64',
+        'ppc64le': 'ppc64le',   # Power PC
+        's390x': 's390x',       # IBM S390x
     }
     sysinfo = {
         'system': platform.system().lower(),
@@ -582,6 +594,10 @@ def urlopen(url):
     home_url = "https://github.com/ekalinin/nodeenv/"
     headers = {'User-Agent': 'nodeenv/%s (%s)' % (nodeenv_version, home_url)}
     req = urllib2.Request(url, None, headers)
+    if ignore_ssl_certs:
+        context = ssl.SSLContext()
+        context.verify_mode = ssl.CERT_NONE
+        return urllib2.urlopen(req, context=context)
     return urllib2.urlopen(req)
 
 # ---------------------------------------------------------
@@ -1018,6 +1034,9 @@ def main():
         exit(1)
 
     global src_base_url
+    global ignore_ssl_certs
+
+    ignore_ssl_certs = opt.ignore_ssl_certs
 
     src_domain = None
     if opt.mirror:
@@ -1074,10 +1093,10 @@ set -e NODE_VIRTUAL_ENV_DISABLE_PROMPT
 }
 
 SHIM = """#!/usr/bin/env bash
-export NODE_PATH=__NODE_VIRTUAL_ENV__/lib/node_modules
-export NPM_CONFIG_PREFIX=__NODE_VIRTUAL_ENV__
-export npm_config_prefix=__NODE_VIRTUAL_ENV__
-exec __SHIM_NODE__ "$@"
+export NODE_PATH='__NODE_VIRTUAL_ENV__/lib/node_modules'
+export NPM_CONFIG_PREFIX='__NODE_VIRTUAL_ENV__'
+export npm_config_prefix='__NODE_VIRTUAL_ENV__'
+exec '__SHIM_NODE__' "$@"
 """
 
 ACTIVATE_BAT = r"""
